clear all
close all
clc

%addpath(['lib/']) %add library when you use code first

%uncomment the following options if you want to see the plot for different
%datasets

%%% HCP %%%
% dataset='HCPr900';
% agebounds=[22 26 30 34];
%NOTE TO RUN THE HCP, please request the adequate mat files from
%yujiang.wang@ncl.ac.uk. This is because this file contains the exact age
%for all the subject, which is part of HCP's restricted access metadata.
%Thus it cannot be published publically. When you request this from
%Yujiang, please state that you have signed up and acknowledged the
%neccessary parts of the terms and conditions on the HCP website to obtain
%the restricted access data.

%%% NKI %%%
dataset='NKI';
agebounds=[15:10:85];


%%% IXI %%%
% dataset='IXI';
% agebounds=[15:10:85];


% %%% ADNI %%%
% dataset='ADNI';
% agebounds=[55:10:95];


spacestr='Ae~At*sqrtT';

%% set age range & gender
load([ 'data_collated/' dataset '.mat'])

load([ 'data_collated/LobeSegment/' dataset '_LobesExtract_ALL.mat'])

eval(['Data=' dataset ';'])


Age=Data.Age;
Gender=categorical(Data.Gender);

d=diff(agebounds);
agecatmid=agebounds(1:end-1)+d(1)/2;

if isfield(Data,'Site')
Site=categorical(Data.Site);
end

if isfield(Data,'Diagnosis')
PatCtrl=categorical(Data.Diagnosis);
PatCtrl=categorical(PatCtrl);
cPatCtrl=categories(PatCtrl);
else
    cPatCtrl=0;
end



%healthy:
mod=Age>0;

if strcmp(dataset,'IXI')
%IXI:
% Site=Data.Site;
mod=Age>0 & categorical(Site)=='Guys';
end

if strcmp(dataset,'ADNI')
%ADNI:
mod=Age>0 & Data.inNonLgt==1;
end


% if strcmp(dataset,'NUSchizo')
% %ADNI:
% mod=Age>0 & (PatCtrl=='No_Known_Disorder' | PatCtrl=='Schizophrenia_Strict');
% end


%% setup stuff to plot


SLOPE=[];
SLOPEU=[];
SLOPEL=[];


LOBE=[];
KCORRECTION=[];
AGECAT=[];
AGE=[];
GENDER=[];
PATCTRL=[];
OFFSET=[];
THICKNESS=[];

for a=1:length(agebounds)-1
for cpc=1:length(cPatCtrl)
    if length(cPatCtrl)>1
        modd=PatCtrl==cPatCtrl{cpc};
    else
        modd=mod;
    end
    for gs=1:3
        if gs==1
        ids=find(Age>=agebounds(a) & Age<agebounds(a+1) & Data.AvgCortThickness(:,1)>0 & Gender=='m' & mod & modd);
        elseif gs==2
        ids=find(Age>=agebounds(a) & Age<agebounds(a+1) & Data.AvgCortThickness(:,1)>0 & Gender=='f' & mod & modd);
        else
        ids=find(Age>=agebounds(a) & Age<agebounds(a+1) & Data.AvgCortThickness(:,1)>0 & mod & modd);
        end

        %whole hemisphere
        [x,y]=getxy(Data.PialArea(ids,:),Data.SmoothPialArea(ids,:),Data.AvgCortThickness(ids,:),spacestr);
        x=[x(:,1);x(:,2)];
        y=[y(:,1);y(:,2)];
        thck=[Data.AvgCortThickness(ids,1);Data.AvgCortThickness(ids,2)];

        X=[ones(size(x)) x];
        [b,bint]=regress(y,X);

        SLOPE=[SLOPE; b(2)];
        SLOPEU=[SLOPEU; bint(2,2)];
        SLOPEL=[SLOPEL; bint(2,1)];
        LOBE=[LOBE;-1];%lobe
        OFFSET=[OFFSET;0];
        THICKNESS=[THICKNESS;0];
        KCORRECTION=[KCORRECTION;0];%corrected?
        AGECAT=[AGECAT;agecatmid(a)];
        AGE=[AGE;agecatmid(a)];
        GENDER=[GENDER;gs];
        PATCTRL=[PATCTRL;cpc];

        % lobe corr by CHS
        MEx=zeros(length(ids)*2,4);
        MEy=MEx;
        for l=2:5
            c=4*pi./K_CHwoBAll(ids,l,:);
            
            %include insular
            if l<5
                S=sum(TotalAreaAll(ids,2:4,:),2);
                R=TotalAreaAll(ids,l,:)./S;
                TA=TotalAreaAll(ids,l,:)+R.*TotalAreaAll(ids,6,:);
            else
                TA=TotalAreaAll(ids,l,:);
            end
            
            [xlc,ylc]=getxy(TA.*c,SmoothAreaAll(ids,l,:).*c,AvgThicknessAll(ids,l,:),spacestr);
            xlc=[xlc(:,:,1);xlc(:,:,2)];
            ylc=[ylc(:,:,1);ylc(:,:,2)];




            MEx(:,l-1)=xlc;
            MEy(:,l-1)=ylc;

        end
        
        
        
        slopekk=zeros(size(MEx,1),1);
        for kk=1:size(MEx,1)
            Xkk=[ones(4,1) MEx(kk,:)'];
            
            S=cov(MEx(kk,:)',MEy(kk,:)');
            u=(2*S(1,1))/sqrt(5*S(1,1)^2 + 2*S(1,1)*S(2,2) + S(2,2)^2);
            Sg = (-S(1,1)^2 + S(1,1)*S(2,2))/(3*S(1,1) + S(2,2));
            Sk = (5*S(1,1)^2 + 2*S(1,1)*S(2,2) + S(2,2)^2)/(3*S(1,1) + S(2,2));
            r=acos(u);
            slope_k=tan(r);
            slopekk(kk)=slope_k;
            
        end
        
        age_s=Age(ids);
        
        SLOPE=[SLOPE; slopekk];
        OFFSET=[OFFSET;y-1.25*x];
        THICKNESS=[THICKNESS;thck];
        SLOPEU=[SLOPEU; zeros(length(ids)*2,1)];
        SLOPEL=[SLOPEL; zeros(length(ids)*2,1)];
        AGE=[AGE;age_s;age_s];
        LOBE=[LOBE;ones(length(ids)*2,1)];%lobe
        KCORRECTION=[KCORRECTION;ones(length(ids)*2,1)];%corrected?
        AGECAT=[AGECAT;ones(length(ids)*2,1)*agecatmid(a)];
        GENDER=[GENDER;ones(length(ids)*2,1)*gs];
        PATCTRL=[PATCTRL;ones(length(ids)*2,1)*cpc];
    end
    
    
end 
end

%%
% 
lctmp=cell(size(LOBE));
lctmp(LOBE==-1)={'Hemisphere'};
lctmp(LOBE==1)={'Lobe.Frontal'};
lctmp(LOBE==2)={'Lobe.Parietal'};
lctmp(LOBE==3)={'Lobe.Temporal'};
lctmp(LOBE==4)={'Lobe.Occipital'};
LOBE=lctmp;
% 
% cctmp=cell(size(KCORRECTION));
% cctmp(KCORRECTION==0)={'Uncorrected'};
% cctmp(KCORRECTION==1)={'Corrected by Gaussian curv'};
% KCORRECTION=cctmp;

% actmp=cell(size(AGECAT));
% actmp(AGECAT==1)={'22-25'};
% actmp(AGECAT==2)={'26-29'};
% actmp(AGECAT==3)={'30-33'};
% AGECAT=actmp;

cctmp=cell(size(GENDER));
cctmp(GENDER==1)={'male'};
cctmp(GENDER==2)={'female'};
cctmp(GENDER==3)={'both'};
GENDER=cctmp;

if cpc>1
cctmp=cell(size(PATCTRL));
cctmp(PATCTRL==1)=cPatCtrl(1);
cctmp(PATCTRL==2)=cPatCtrl(2);

PATCTRL=cctmp;
end


%% Plot slopes for all the age categories (and pat vs controls - i.e. Fig 4A)

close all
clear g
g=gramm('x',AGECAT-1,'y',SLOPE,'ymin',SLOPEL,'ymax',SLOPEU,'subset',KCORRECTION==0&categorical(GENDER)=='both');
g.facet_grid(PATCTRL,[],'scale','fixed');
%g.stat_glm();

%g.geom_line();
g.geom_point();
g.geom_interval('geom','errorbar');
g.set_color_options('map',[0.7 0.7 0.7])
%g.set_point_options('base_size',10)

g.set_names('row','Diagnosis','column','Gender','x','Age','y','Slope');
g.set_title(dataset);


g.update('x',AGECAT+0.5,'y',SLOPE,'subset',KCORRECTION==1&categorical(GENDER)=='both','color',PATCTRL)
g.stat_boxplot('width',0.2);
g.set_color_options('map',[255 0 0;0 110 130]/255)

xmin=agebounds(1);
xmax=agebounds(end);
g.axe_property('YLim',[1 1.5],'XLim',[xmin xmax])

g.geom_hline('yintercept',1.25);
for a=1:length(agebounds)
    g.geom_vline('xintercept',agebounds(a));
end

%figure('Position',[0 0 1500 800]);
g.draw();

